@@ -126,7 +126,7 @@ sv_waterfall.shapviz <- function(object, row_id = 1L, max_display = 10L,
       axis.line.x = ggplot2::element_line(),
       axis.ticks.y = ggplot2::element_blank()
     ) +
-    ggplot2::labs(y = ggplot2::element_blank(), x = "SHAP value")
+    ggplot2::labs(y = ggplot2::element_blank(), x = "Prediction")
 
   if (show_connection) {
     p <- p +
